==> ep-framework-wordpress-1.5.3-399802.tar: src/Plugin/Core/Mail.php <==
<?php
namespace Ep\Wp\Plugin\Core;

use Ep\Wp\Plugin\PluginInterface;
use Zend\Mail\AddressList;
use Zend\Mail\Headers;
use Zend\Mail\Message;
use Zend\Mail\Transport\TransportInterface;

/**
 * Omogućava korištenje našeg mailera za slanje mailova.
 *
 * @package Ep\Wp\Plugin
 * @author Elektronika Perhoč <web@ep.hr>
 * @link http://gitlab.ep.local/ep-framework/wordpress
 */
class Mail implements PluginInterface
{
    /** @var TransportInterface */
    protected $transport;

    /**
     * Mail constructor.
     *
     * @param TransportInterface $transport
     */
    public function __construct(TransportInterface $transport)
    {
        $this->transport = $transport;
    }

    /**
     * Dodaje akcije i filtere u WordPress.
     *
     * @return void
     */
    public function __invoke(): void
    {
        add_filter('ep_mail', [$this, 'wp_mail'], 10, 5);
    }

    function wp_mail($to, $subject, $message, $headers = '')
    {
        if (is_array($headers)) {
            $headers = implode("\r\n", $headers);
        }

        $headers = preg_replace('/>; charset=UTF-8/', '>', $headers);
        $headers = preg_replace('/\[your-name\]/', $_POST['your-name'] ?? 'Webshop korisnik', $headers);

        if (!preg_match('/\r\n/', $headers)) {
            $headers = preg_replace('/\n/', "\r\n", $headers);
        }

        $headers = strtr($headers, [
            'Š' => 'S',
            'Đ' => 'DJ',
            'Č' => 'C',
            'Ć' => 'C',
            'Ž' => 'Z',
            'š' => 's',
            'đ' => 'dj',
            'č' => 'c',
            'ć' => 'c',
            'ž' => 'z',
        ]);

        $mail = new Message();
        $mail->setHeaders(Headers::fromString($headers));
        $mail->getHeaders()->setEncoding('utf-8');

        if (preg_match('/,/', $to)) {
            $tos = array_map('trim', explode(',', $to));

            $to = new AddressList();
            $to->addMany($tos);
        }

        $mail->addTo($to);
        $mail->setSubject(preg_replace('/\[your-subject\]/', '', $subject));
        $mail->setBody($message);

        if (!$mail->getHeaders()->has('Content-Type')) {
            $mail->getHeaders()->addHeaderLine('Content-Type', 'text/html; charset=utf-8');
        }

        if (count($mail->getFrom()) === 0) {
            $from_name = apply_filters('wp_mail_from_name', get_bloginfo('name'));

            // Get the site domain and get rid of www.
            $sitename = strtolower( $_SERVER['SERVER_NAME'] );
            if ( substr( $sitename, 0, 4 ) == 'www.' ) {
                $sitename = substr( $sitename, 4 );
            }
            $from_email = apply_filters('wp_mail_from', 'webshop@' . $sitename);

            $mail->setFrom($from_email, $from_name);
        }

        try {
            $this->transport->send($mail);
        } catch (\Exception $e) {
            return false;
        }

        return true;
    }
}

==> ep-framework-wordpress-1.5.5-1025a3.tar: src/Plugin/Core/Mail.php <==
<?php
namespace Ep\Wp\Plugin\Core;

use Ep\Wp\Plugin\PluginInterface;
use Laminas\Mail\AddressList;
use Laminas\Mail\Headers;
use Laminas\Mail\Message;
use Laminas\Mail\Transport\TransportInterface;

/**
 * Omogućava korištenje našeg mailera za slanje mailova.
 *
 * @package Ep\Wp\Plugin
 * @author Elektronika Perhoč <web@ep.hr>
 * @link http://gitlab.ep.local/ep-framework/wordpress
 */
class Mail implements PluginInterface
{
    /** @var TransportInterface */
    protected $transport;

    /**
     * Mail constructor.
     *
     * @param TransportInterface $transport
     */
    public function __construct(TransportInterface $transport)
    {
        $this->transport = $transport;
    }

    /**
     * Dodaje akcije i filtere u WordPress.
     *
     * @return void
     */
    public function __invoke(): void
    {
        add_filter('ep_mail', [$this, 'wp_mail'], 10, 5);
    }

    function wp_mail($to, $subject, $message, $headers = '')
    {
        if (is_array($headers)) {
            $headers = implode("\r\n", $headers);
        }

        $headers = preg_replace('/>; charset=UTF-8/', '>', $headers);
        $headers = preg_replace('/\[your-name\]/', $_POST['your-name'] ?? 'Webshop korisnik', $headers);

        if (!preg_match('/\r\n/', $headers)) {
            $headers = preg_replace('/\n/', "\r\n", $headers);
        }

        $headers = strtr($headers, [
            'Š' => 'S',
            'Đ' => 'DJ',
            'Č' => 'C',
            'Ć' => 'C',
            'Ž' => 'Z',
            'š' => 's',
            'đ' => 'dj',
            'č' => 'c',
            'ć' => 'c',
            'ž' => 'z',
        ]);

        $mail = new Message();
        $mail->setHeaders(Headers::fromString($headers));
        $mail->getHeaders()->setEncoding('utf-8');

        if (preg_match('/,/', $to)) {
            $tos = array_map('trim', explode(',', $to));

            $to = new AddressList();
            $to->addMany($tos);
        }

        $mail->addTo($to);
        $mail->setSubject(preg_replace('/\[your-subject\]/', '', $subject));
        $mail->setBody($message);

        if (!$mail->getHeaders()->has('Content-Type')) {
            $mail->getHeaders()->addHeaderLine('Content-Type', 'text/html; charset=utf-8');
        }

        if (count($mail->getFrom()) === 0) {
            $from_name = apply_filters('wp_mail_from_name', get_bloginfo('name'));

            // Get the site domain and get rid of www.
            $sitename = strtolower( $_SERVER['SERVER_NAME'] );
            if ( substr( $sitename, 0, 4 ) == 'www.' ) {
                $sitename = substr( $sitename, 4 );
            }
            $from_email = apply_filters('wp_mail_from', 'webshop@' . $sitename);

            $mail->setFrom($from_email, $from_name);
        }

        try {
            $this->transport->send($mail);
        } catch (\Exception $e) {
            return false;
        }

        return true;
    }
}
